@@ -53,7 +53,6 @@ int main(int argc, char *argv[])
         extern int optind;
         extern int opterr;
         extern int optopt;
-
 #ifdef HAVE_LOCALE_H
 	char *locptr;
 #endif
@@ -72,7 +71,7 @@ int main(int argc, char *argv[])
 	do_output = 0;
 	do_signals = 1;
 	do_version = 0;
-	do_tempoutput = 0;
+	do_tempoutput = 1;
 	while((c = getopt(argc, argv, "cd:hosv")) > 0) {
 		switch(c) {
 		case 'c':
@@ -97,7 +96,6 @@ int main(int argc, char *argv[])
 			exit(EXIT_FAILURE);
 		}
 	}
-	do_tempoutput = 1;
 	if(do_help) {
 		oer_debug(OER_DEBUG_INFO, "%s: oer [-c] [-d <level>] [-h] [-o] [-s] [-v]\n", argv[0]);
 		exit(EXIT_SUCCESS);
@@ -122,7 +120,7 @@ int main(int argc, char *argv[])
 		}
 		if(newpid) {
 			/* the parent */
-			oer_debug(OER_DEBUG_INFO, "main->fork successful, oer new pid is %ld (parent exiting)\n", newpid);
+			oer_debug(OER_DEBUG_INFO, "main->fork successful, oer running in background (child pid is %ld, parent exiting)\n", newpid);
 			exit(EXIT_SUCCESS);
 		}
 		/* necessary for some remote progs */
@@ -152,10 +150,6 @@ int main(int argc, char *argv[])
 		exit(EXIT_FAILURE);
 	}
 	strncpy(mystate->progname, argv[0], STRINGLEN);
-	if(!loadall()) {
-		oer_debug(OER_DEBUG_INFO, "main->loadall() failed\n");
-		exit(EXIT_FAILURE);
-	}
 	if(do_output) {
 		snprintf(stringbuffer, WRITE_BUFFER_LENGTH, "oer-%d.output", getpid());
 		if((mystate->logto = fopen(stringbuffer, "a+")) == NULL) {
@@ -164,6 +158,12 @@ int main(int argc, char *argv[])
 		}
 		oer_debug(OER_DEBUG_INFO, "main->debug output gets logged to %s\n", stringbuffer);
 	}
+	do_tempoutput = 0;
+	/* from now on we write to console and/or file */
+	if(!loadall()) {
+		oer_debug(OER_DEBUG_INFO, "main->loadall() failed\n");
+		exit(EXIT_FAILURE);
+	}
 	if(index(mystate->flags, (int)'l') != NULL) {
 		snprintf(stringbuffer, WRITE_BUFFER_LENGTH, "oer-%d.raw", getpid());
 		if((mystate->logfp = fopen(stringbuffer, "a+")) == NULL) {
@@ -172,14 +172,15 @@ int main(int argc, char *argv[])
 		}
 		oer_debug(OER_DEBUG_INFO, "main->IRC traffic gets logged to %s\n", stringbuffer);
 	}
-	/* from now on we write to console and/or file */
-	do_tempoutput = 0;
 	establishconnection();
         if(mystate->bailout) {
                 exit(EXIT_FAILURE);
         }
 	mystate->loopforever = 1;
 	while(mystate->loopforever) {
+#ifdef DEBUG
+        oer_debug(OER_DEBUG_FLOOD, "main->mainloop\n");
+#endif
 		FD_ZERO(&rsock);
 		FD_SET(mystate->sockfd, &rsock);
 		tv.tv_sec = OER_MAINLOOP_TIMEOUT_SECS;
@@ -187,7 +188,9 @@ int main(int argc, char *argv[])
 		retval = select(mystate->sockfd + 1, &rsock, NULL, NULL, &tv);
 		mystate->now = time(NULL);
 		if(retval < 0) {
+#ifdef DEBUG
 			oer_debug(OER_DEBUG_INFO, "main->select() failed: %s\n", strerror(errno));
+#endif
 			if(errno != EINTR) {
 				mystate->reconnect = OER_RECONNECT_ERROR;
 				reconnect();
@@ -241,8 +244,13 @@ int main(int argc, char *argv[])
 
 static void handlesignal(int signal)
 {
+#ifdef DEBUG
+        oer_debug(OER_DEBUG_FLOOD, "handlesignal(%d)\n", signal);
+#endif
 	if(signal == SIGHUP) {
+#ifdef DEBUG
 		oer_debug(OER_DEBUG_INFO, "handlesignal->received SIGHUP, flushing disk I/O\n");
+#endif
 		flushall();
 		return;
 	}
@@ -253,7 +261,9 @@ static void handlesignal(int signal)
 			return;
 			
 		} else {
+#ifdef DEBUG
 			oer_debug(OER_DEBUG_INFO, "handlesignal->%s received, ignoring (do_signals = 0)\n", (signal == SIGINT) ? "SIGINT" : "SIGTERM");
+#endif
 		}
 	}
 	if(signal == SIGPIPE) {
